pystagram.graph_api.components.tags package — pystagram 0.1 documentation

# pystagram.graph_api.components.tags package

## Submodules

## pystagram.graph_api.components.tags.product_tag module

class pystagram.graph_api.components.tags.product_tag.ProductTag(product_id: str, x: float, y: float, merchant_id: str | None = None)

  Bases: `Tag`

  Instagram Product Tag.

  Parameters:

    - product_id (str) – Product id.

    - x (float) – X coordinate. Range: [0, 1].

    - y (float) – Y coordinate. Range: [0, 1].

    - merchant_id (Optional[str]) – Merchant id.

  dict() → dict

    Return a dictionary representation of the tag.

  info() → dict

    Return an alternative dictionary representation of the tag.

## pystagram.graph_api.components.tags.product_tag 2 module

## pystagram.graph_api.components.tags.product_tag 3 module

## pystagram.graph_api.components.tags.product_tag 4 module

## pystagram.graph_api.components.tags.product_tag 5 module

## pystagram.graph_api.components.tags.tag module

class pystagram.graph_api.components.tags.tag.Tag

  Bases: `ABC`

  Abstract class for an Instagram Tag.

  abstract dict() → dict

## pystagram.graph_api.components.tags.tag 2 module

## pystagram.graph_api.components.tags.tag 3 module

## pystagram.graph_api.components.tags.tag 4 module

## pystagram.graph_api.components.tags.tag 5 module

## pystagram.graph_api.components.tags.user_tag module

class pystagram.graph_api.components.tags.user_tag.UserTag(username: str, x: float, y: float)

  Bases: `Tag`

  dict() → dict

## pystagram.graph_api.components.tags.user_tag 2 module

## pystagram.graph_api.components.tags.user_tag 3 module

## pystagram.graph_api.components.tags.user_tag 4 module

## pystagram.graph_api.components.tags.user_tag 5 module

## pystagram.graph_api.components.tags.user_tag 6 module

## Module contents